CompiledIntervalTruth

Enum CompiledIntervalTruth 

pub enum CompiledIntervalTruth {
    AlwaysTrue,
    AlwaysFalse,
    MaybeTrue,
}
Result of evaluating a compiled time predicate against a segment.

Variants



AlwaysTrue

Predicate always true over the segment interval.



AlwaysFalse

Predicate always false over the segment interval.



MaybeTrue

Predicate may be true for some values in the segment interval.